@@ -5,7 +5,7 @@ import os
 import re
 import sqlite3
 from contextlib import suppress
-from sqlite3 import OperationalError
+from sqlite3 import OperationalError, ProgrammingError
 from typing import Dict, List, Type, Union
 
 from pypika import Query, Table, functions
@@ -271,14 +271,23 @@ class PypikaRepository(Repository):
                 log.debug("Rolling back the database migrations")
                 try:
                     backend.rollback_migrations(backend.to_rollback(migrations))
-                except Exception as error:  # noqa: W0703
+                except Exception as rollback_error:  # noqa: W0703
                     # We need to add tests for this function and use a less generic
                     # exception
                     log.error("Error rolling back database migrations")
-                    log.error(error)
-                    raise error
+                    log.error(rollback_error)
+                    raise rollback_error from error
             log.debug("Complete running database migrations")
 
     def close(self) -> None:
         """Close the connection to the database."""
         self.connection.close()
+
+    @property
+    def is_closed(self) -> bool:
+        """Inform if the connection is closed."""
+        try:
+            self.connection.cursor()
+            return False
+        except ProgrammingError:
+            return True
