@@ -3,6 +3,8 @@
 from datetime import datetime
 from typing import List, Optional
 
+from pydantic import AnyHttpUrl
+
 from repository_orm import Entity as EntityModel
 
 
@@ -42,6 +44,14 @@ class Genre(Entity):
     _skip_on_merge: List[str] = ["rating"]
 
 
+class Article(Entity):
+    """Entity to model an internet article."""
+
+    id_: AnyHttpUrl
+    description: Optional[str] = None
+    rating: Optional[int] = None
+
+
 class OtherEntity(Entity):
     """Entity to model an entity that is not in the repo."""
 
